//
// Copyright (c) 2022, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Diagramming.WinForms.Samples.CS.Routing
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void MainForm_Load(object sender, EventArgs e)
		{
			diagram.LinkRouter = new GridRouter();

			int x, y;
			for (y = 0; y < 10; y++)
			{
				int xOffset;
				xOffset = (y % 2) * 16;

				for (x = 0; x < 10; x++)
				{
					ShapeNode node = new ShapeNode(diagram);
					node.Bounds = new RectangleF(
						10 + xOffset, 10 + y * 32, (10 + (x % 2) * 10), 10);
					diagram.Nodes.Add(node);

					xOffset = xOffset + 32;
					xOffset = xOffset + (x % 2) * 10;
				}
			}

			diagram.ResizeToFitItems(10);
			diagramView.AutoScroll = true;

			//route arrows while they are being created
			diagram.RoutingOptions.TriggerRerouting = RerouteLinks.WhileCreating | RerouteLinks.WhenModified;

			diagram.RouteLinks = true;
			diagram.LinkShape = LinkShape.Cascading;
            diagram.ShapeNodeStyle.Brush = new MindFusion.Drawing.LinearGradientBrush(Color.FromArgb(224, 233, 233),
                Color.FromArgb(102, 154, 204));

			turnCostTrB.Value = diagram.RoutingOptions.TurnCost;
			turnCostLb.Text = "Turn cost: " + turnCostTrB.Value;

			crossingCostTrB.Value = diagram.RoutingOptions.CrossingCost;
			crossingCostLb.Text = "Crossing cost: " + crossingCostTrB.Value;

			lengthCostTrB.Value = diagram.RoutingOptions.LengthCost;
			lengthCostLb.Text = "Length cost: " + lengthCostTrB.Value;

			nodeVicCostTrB.Value = diagram.RoutingOptions.NodeVicinityCost;
			nodeVicCostLb.Text = "Node vicinity cost: " + nodeVicCostTrB.Value;

			nodeVicSizeTrB.Value = (byte)diagram.RoutingOptions.NodeVicinitySize;
			nodeVicSizeLb.Text = "Node vicinity size: " + nodeVicSizeTrB.Value;
		}

		private void turnCostTrB_Scroll(object sender, EventArgs e)
		{
			diagram.RoutingOptions.TurnCost = (byte)turnCostTrB.Value;
			turnCostLb.Text = "Turn cost: " + turnCostTrB.Value;
		}

		private void crossingCostTrB_Scroll(object sender, EventArgs e)
		{
			diagram.RoutingOptions.CrossingCost = (byte)crossingCostTrB.Value;
			crossingCostLb.Text = "Crossing cost: " + crossingCostTrB.Value;
		}

		private void lengthCostTrB_Scroll(object sender, EventArgs e)
		{
			diagram.RoutingOptions.LengthCost = (byte)lengthCostTrB.Value;
			lengthCostLb.Text = "Length cost: " + lengthCostTrB.Value;
		}

		private void nodeVicCostTrB_Scroll(object sender, EventArgs e)
		{
			diagram.RoutingOptions.NodeVicinityCost = (byte)nodeVicCostTrB.Value;
			nodeVicCostLb.Text = "Node vicinity cost: " + nodeVicCostTrB.Value;
		}

		private void nodeVicSizeTrB_Scroll(object sender, EventArgs e)
		{
			diagram.RoutingOptions.NodeVicinitySize = nodeVicSizeTrB.Value;
			nodeVicSizeLb.Text = "Node vicinity size: " + nodeVicSizeTrB.Value;
		}

		private void rerouteAllArrowsBtn_Click(object sender, EventArgs e)
		{
			diagram.RouteAllLinks();
		}
	}
}